Package: shinyglide
Type: Package
Title: Glide Component for Shiny Applications
Version: 0.1.4
Date: 2023-02-15
Authors@R: c(
    person("Julien", "Barnier", 
           role=c("aut","cre"),
           email="julien.barnier@cnrs.fr")
    )
Maintainer: Julien Barnier <julien.barnier@cnrs.fr>
Description: Insert Glide JavaScript component into Shiny applications for
    carousel or assistant-like user interfaces.
License: GPL (>= 3)
VignetteBuilder: knitr
URL: https://juba.github.io/shinyglide/,
        https://github.com/juba/shinyglide
BugReports: https://github.com/juba/shinyglide/issues
Encoding: UTF-8
Imports: shiny (>= 1.2.0), htmltools
Suggests: knitr, rmarkdown
RoxygenNote: 7.1.2
NeedsCompilation: no
Packaged: 2023-02-15 10:11:06 UTC; julien
Author: Julien Barnier [aut, cre]
Repository: CRAN
Date/Publication: 2023-02-15 10:40:02 UTC
Built: R 4.6.0; ; 2026-04-26 15:08:44 UTC; unix
